@@ -26,6 +26,8 @@ __all__ = (
     "ListPipelinesPaginatorName",
     "ListPresetsPaginatorName",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -304,10 +306,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -315,3 +319,7 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_jobs_by_pipeline", "list_jobs_by_status", "list_pipelines", "list_presets"
+]
+WaiterName = Literal["job_complete"]
